package info.textgrid.middleware;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.elasticsearch.client.Client;
import org.elasticsearch.client.transport.TransportClient;
import org.elasticsearch.common.settings.ImmutableSettings;
import org.elasticsearch.common.settings.Settings;
import org.elasticsearch.common.transport.InetSocketTransportAddress;

/**
 * Establishing to connection to an ElasticSearch client
 * 
 * @author Maximilian Brodhun
 * @version 1.0
 * @since 09.01.2014
 *
 */
public class OAI_ESClient {

  private Log log = LogFactory.getLog(OAI_ESClient.class);
  private static String url;
  private static int port;
  private static String esCluster;
  private static String esIndex;
  private static String esType;
  public static Client oaiESClient;

  /**
   * Constructor for the connection to an ElasticSearch index
   * 
   * @param url address for the ELasticSearch connection
   * @param port for the ElasticSearch connection
   * @param clusterName indicating the name of the cluster where the index exists
   */
  @SuppressWarnings("resource")
  public OAI_ESClient(String url, String thePort, String clusterName) {

    int port = Integer.parseInt(thePort);

    this.log.info("ElasticSearch connection settings:");
    this.log.info("url = " + url);
    this.log.info("port = " + port);
    this.log.info("cluster name = " + clusterName);

    OAI_ESClient.setUrl(url);
    OAI_ESClient.setPort(port);

    Settings oaiESClusterSettings =
        ImmutableSettings.settingsBuilder().put("cluster.name", clusterName).build();

    oaiESClient = new TransportClient(oaiESClusterSettings)
        .addTransportAddress(new InetSocketTransportAddress(url, port));
  }

  /**
   * 
   * @return esIndex
   */
  public static String getEsIndex() {
    return esIndex;
  }

  /**
   * 
   * @param esIndex
   */
  public static void setEsIndex(String esIndex) {
    OAI_ESClient.esIndex = esIndex;
  }

  /**
   * 
   * @return esType
   */
  public static String getEsType() {
    return esType;
  }

  /**
   * 
   * @param esType
   */
  public static void setEsType(String esType) {
    OAI_ESClient.esType = esType;
  }

  /**
   * 
   * @return oaiESClient
   */
  public static Client getOaiESClient() {
    return oaiESClient;
  }

  /**
   * 
   * @return esCluster
   */
  public static String getClusterName() {
    return esCluster;
  }

  /**
   * 
   * @param esCluster
   */
  public static void setClusterName(String esCluster) {
    OAI_ESClient.esCluster = esCluster;
  }

  /**
   * 
   * @return url
   */
  public static String getUrl() {
    return url;
  }

  /**
   * 
   * @param url
   */
  public static void setUrl(String url) {
    OAI_ESClient.url = url;
  }

  /**
   * 
   * @return port
   */
  public static int getPort() {
    return port;
  }

  /**
   * 
   * @param port
   */
  public static void setPort(int port) {
    OAI_ESClient.port = port;
  }

  /**
   * 
   * @param oaiClient
   */
  public static void setOaiESClient(Client theOaiClient) {
    OAI_ESClient.oaiESClient = theOaiClient;
  }

}
